@@ -1,5 +1,3 @@
-/* $Id: loadavg.c 2422 2005-12-12 09:38:15Z jamesh $ */
-
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -39,7 +37,7 @@ static const unsigned long _glibtop_sysdeps_loadavg =
 /* Init function. */
 
 void
-glibtop_init_loadavg_s (glibtop *server)
+_glibtop_init_loadavg_s (glibtop *server)
 {
 	server->sysdeps.loadavg = _glibtop_sysdeps_loadavg;
 }
